@@ -4,8 +4,12 @@
  See LICENSE file in the distribution.
 \********************************************************************/
 
-#ifndef _MKC_SYS_TREE_H_
-#define _MKC_SYS_TREE_H_
+#ifndef _MKC_RB_H_
+#define _MKC_RB_H_
+
+#ifndef _MKC_CHECK_RB
+# error "Missing MKC_FEATURES += RB"
+#endif
 
 #if defined(HAVE_DEFINE_RB_ENTRY_SYS_TREE_H) && defined(HAVE_DEFINE_SPLAY_ENTRY_SYS_TREE_H)
 #include <sys/tree.h>
@@ -13,4 +17,4 @@
 #include "netbsd_sys_tree.h"
 #endif
 
-#endif // _MKC_SYS_TREE_H_
+#endif // _MKC_RB_H_
